## Version 0.37.0 (2021-05-04)
### 🎉 New features

- order: add support for order by NULLS LAST and NULLS FIRST
- typing: add partial typing

### 🤖 Continuous integration

- integrate pytest-deprecated-warnings
- mypy: enable mypy check on the ci
